==> cs-2.6.zip: cs/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Obsah';
$GLOBALS['__l10n']['To menu'] = 'Menu';
$GLOBALS['__l10n']['To search'] = 'Vyhledávání';
$GLOBALS['__l10n']['By'] = 'Od';
$GLOBALS['__l10n']['by'] = 'od';
$GLOBALS['__l10n']['on'] = 'v';
$GLOBALS['__l10n']['On'] = 'v';
$GLOBALS['__l10n']['Continue reading'] = 'Číst dál...';
$GLOBALS['__l10n']['no comment'] = 'žádné komentáře';
$GLOBALS['__l10n']['one comment'] = 'jeden komentář';
$GLOBALS['__l10n']['%d comments'] = '%d komentářů(e)';
$GLOBALS['__l10n']['no trackback'] = 'žádné trackbacky';
$GLOBALS['__l10n']['one trackback'] = 'jeden trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackbacků(y)';
$GLOBALS['__l10n']['no attachment'] = 'žádná příloha';
$GLOBALS['__l10n']['one attachment'] = 'jedna příloha';
$GLOBALS['__l10n']['%d attachments'] = '%d příloh(y)';
$GLOBALS['__l10n']['previous entries'] = 'přechozí články';
$GLOBALS['__l10n']['page'] = 'strana';
$GLOBALS['__l10n']['of'] = 'ze';
$GLOBALS['__l10n']['next entries'] = 'následující články';
$GLOBALS['__l10n']['Search'] = 'Vyhledávání';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Žádne výsledky pro hledání <em>%1$s</em>.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Hledání výrazu "<em>%1$s</em>" vrátilo <strong>%2$s</strong> výsledek.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Hledání výrazu "<em>%1$s</em>" vrátilo <strong>%2$s</strong> výsledky.';
$GLOBALS['__l10n']['Home'] = 'Úvod';
$GLOBALS['__l10n']['All keywords'] = 'Všechny štítky';
$GLOBALS['__l10n']['Best of me'] = 'Nejlepší šlánky';
$GLOBALS['__l10n']['Languages'] = 'Jazyky';
$GLOBALS['__l10n']['Categories'] = 'Kategorie';
$GLOBALS['__l10n']['Subcategories'] = 'Podkategorie';
$GLOBALS['__l10n']['Archives'] = 'Archivy';
$GLOBALS['__l10n']['Links'] = 'Odkazy';
$GLOBALS['__l10n']['Subscribe'] = 'Odebírat';
$GLOBALS['__l10n']['Entries feed'] = 'Kanál článků';
$GLOBALS['__l10n']['Comments feed'] = 'Kanál komentářů';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Atom kanál komentářů';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Atom kanál článků kategorie';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Atom kanál komentářů kategorie';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Kanál pro komentáře článku';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Atom kanál pro komentáře článku';
$GLOBALS['__l10n']['Attachments'] = 'Přílohy';
$GLOBALS['__l10n']['Permalink'] = 'Trvalý odkaz';
$GLOBALS['__l10n']['Comments'] = 'Komentáře';
$GLOBALS['__l10n']['Your comment'] = 'Váš komentář';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Váš komentář byl publikován.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Váš komentář byl zaslán a bude předán k moderování.';
$GLOBALS['__l10n']['Add a comment'] = 'Přidat komentář';
$GLOBALS['__l10n']['Name or nickname'] = 'Jméno nebo přeždívka';
$GLOBALS['__l10n']['Email address'] = 'E-mail';
$GLOBALS['__l10n']['Website'] = 'Web';
$GLOBALS['__l10n']['optional'] = 'volitelné';
$GLOBALS['__l10n']['Comment'] = 'Komentář';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML kód bude zobrazen jako text, URL adresy budou automaticky překonvertovány na odkazy.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Zapamatuj si mě';
$GLOBALS['__l10n']['preview'] = 'náhled';
$GLOBALS['__l10n']['send'] = 'poslat';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Jsou publikovány ve stejném tématu';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Musíte uvést jméno autora';
$GLOBALS['__l10n']['You must provide a comment'] = 'Musíte napsat nějaký komentář';
$GLOBALS['__l10n']['Email address is not valid'] = 'E-mailová adresa není správná';
$GLOBALS['__l10n']['Document not found'] = 'Dokument nenalezen';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Dokument, který hledáte, neexistuje.';
$GLOBALS['__l10n']['Powered by %s'] = 'Vytvořil %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Přihlásit se k odběru';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Co je to RSS kanál?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS kanál je univerzálně poskytovaný souhrn blogu. Pomocí nějk jednoduše získáte zahlaví článků a odkazy na jejich plnou verzi. RSS kanál můžete odebírat pomocí svého oblíbeného <a href="http://cs.wikipedia.org/wiki/RSS">agregátoru</a>.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Jednoduše zkopírujte toto URL do vašeho programu pro RSS:';
$GLOBALS['__l10n']['Password needed'] = 'Je vyžadováno heslo';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Musíte zadat heslo přo přístup do této sekce.';
$GLOBALS['__l10n']['Password:'] = 'Heslo:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Musíte vložit validní emailovou adresu.';
$GLOBALS['__l10n']['Read'] = 'Číst';

==> cs-2.10.4.zip: cs/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Obsah';
$GLOBALS['__l10n']['To menu'] = 'Menu';
$GLOBALS['__l10n']['To search'] = 'Vyhledávání';
$GLOBALS['__l10n']['By'] = 'Od';
$GLOBALS['__l10n']['by'] = 'od';
$GLOBALS['__l10n']['on'] = 'v';
$GLOBALS['__l10n']['On'] = 'v';
$GLOBALS['__l10n']['Continue reading'] = 'Číst dál...';
$GLOBALS['__l10n']['no comments'] = 'žádné komentáře';
$GLOBALS['__l10n']['one comment'] = 'jeden komentář';
$GLOBALS['__l10n']['%d comments'] = '%d komentářů(e)';
$GLOBALS['__l10n']['no trackbacks'] = 'žádné trackbacky';
$GLOBALS['__l10n']['one trackback'] = 'jeden trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackbacků(y)';
$GLOBALS['__l10n']['no attachments'] = 'žádná příloha';
$GLOBALS['__l10n']['one attachment'] = 'jedna příloha';
$GLOBALS['__l10n']['%d attachments'] = '%d příloh(y)';
$GLOBALS['__l10n']['previous entries'] = 'přechozí články';
$GLOBALS['__l10n']['page'] = 'strana';
$GLOBALS['__l10n']['of'] = 'ze';
$GLOBALS['__l10n']['next entries'] = 'následující články';
$GLOBALS['__l10n']['Search'] = 'Vyhledávání';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Žádne výsledky pro hledání <em>%1$s</em>.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Hledání výrazu "<em>%1$s</em>" vrátilo <strong>%2$s</strong> výsledek.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Hledání výrazu "<em>%1$s</em>" vrátilo <strong>%2$s</strong> výsledky.';
$GLOBALS['__l10n']['Home'] = 'Úvod';
$GLOBALS['__l10n']['All keywords'] = 'Všechny štítky';
$GLOBALS['__l10n']['Best of me'] = 'Nejlepší šlánky';
$GLOBALS['__l10n']['Languages'] = 'Jazyky';
$GLOBALS['__l10n']['Categories'] = 'Kategorie';
$GLOBALS['__l10n']['Subcategories'] = 'Podkategorie';
$GLOBALS['__l10n']['Archives'] = 'Archivy';
$GLOBALS['__l10n']['Links'] = 'Odkazy';
$GLOBALS['__l10n']['Subscribe'] = 'Odebírat';
$GLOBALS['__l10n']['Entries feed'] = 'Kanál článků';
$GLOBALS['__l10n']['Comments feed'] = 'Kanál komentářů';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Atom kanál komentářů';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Atom kanál článků kategorie';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Atom kanál komentářů kategorie';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Kanál pro komentáře článku';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Atom kanál pro komentáře článku';
$GLOBALS['__l10n']['Attachments'] = 'Přílohy';
$GLOBALS['__l10n']['Permalink'] = 'Trvalý odkaz';
$GLOBALS['__l10n']['Comments'] = 'Komentáře';
$GLOBALS['__l10n']['Your comment'] = 'Váš komentář';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Váš komentář byl publikován.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Váš komentář byl zaslán a bude předán k moderování.';
$GLOBALS['__l10n']['Add a comment'] = 'Přidat komentář';
$GLOBALS['__l10n']['Name or nickname'] = 'Jméno nebo přeždívka';
$GLOBALS['__l10n']['Email address'] = 'E-mail';
$GLOBALS['__l10n']['Website'] = 'Web';
$GLOBALS['__l10n']['optional'] = 'volitelné';
$GLOBALS['__l10n']['Comment'] = 'Komentář';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML kód bude zobrazen jako text, URL adresy budou automaticky překonvertovány na odkazy.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Zapamatuj si mě';
$GLOBALS['__l10n']['preview'] = 'náhled';
$GLOBALS['__l10n']['send'] = 'poslat';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Jsou publikovány ve stejném tématu';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Musíte uvést jméno autora';
$GLOBALS['__l10n']['You must provide a comment'] = 'Musíte napsat nějaký komentář';
$GLOBALS['__l10n']['Email address is not valid'] = 'E-mailová adresa není správná';
$GLOBALS['__l10n']['Document not found'] = 'Dokument nenalezen';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Dokument, který hledáte, neexistuje.';
$GLOBALS['__l10n']['Powered by %s'] = 'Vytvořil %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Přihlásit se k odběru';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Co je to RSS kanál?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS kanál je univerzálně poskytovaný souhrn blogu. Pomocí nějk jednoduše získáte zahlaví článků a odkazy na jejich plnou verzi. RSS kanál můžete odebírat pomocí svého oblíbeného <a href="http://cs.wikipedia.org/wiki/RSS">agregátoru</a>.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Jednoduše zkopírujte toto URL do vašeho programu pro RSS:';
$GLOBALS['__l10n']['Password needed'] = 'Je vyžadováno heslo';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Musíte zadat heslo přo přístup do této sekce.';
$GLOBALS['__l10n']['Password:'] = 'Heslo:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Musíte vložit validní emailovou adresu.';
$GLOBALS['__l10n']['Read'] = 'Číst';
